import { z } from 'zod';
import { routePacketQueryParser } from './parsers';
import { GraphEdgeUnit } from '../../graph/types';
import { RoutableEdgeType, RoutableNodeType } from '../../graph/routing/types';

export type PayinRouteQuery = z.infer<typeof routePacketQueryParser>;
export type PayinRouteResult = {
  endpoints: Array<{
    amt: number;
    packets: Array<{
      amt: number;
      payee: string;
      path: Array<{
        src: string;
        dst: string;
        edgeAmt: number;
        edgeUnit: GraphEdgeUnit;
        transferredAmt: number;
      }>;
    }>;
  }>;
  trace: {
    nodes: {
      uuid: string; // TODO it's a node id but we don't borrow its types; probably should be some intermediate structure
      type: RoutableNodeType;
    }[];
    edges: {
      type: RoutableEdgeType;
      src: string;
      dst: string;
    }[];
  };
};
